@@ -3,7 +3,7 @@ import importlib
 import textwrap
 
 subcommands = [
-    ("service", "task.cli.service"),
+    ("serve", "task.cli.serve"),
 ]
 
 
@@ -38,6 +38,6 @@ def main():
 
 if __name__ == '__main__':
     subcommands = [
-        ("service", "task.cli.service"),
+        ("serve", "task.cli.service"),
     ]
     main()
