@@ -13,18 +13,21 @@ app = FastAPI(
     },
 )
 
+
 @app.post(path="/task")
 def addTask():
     return
 
+
 @app.delete(path="/task")
 def deleteTask():
     return
 
+
 @app.get(path="/task")
 def showTask():
     return
 
 
 if __name__ == '__main__':
-    uvicorn.run(app, host="0.0.0.0", port=8000)
\ No newline at end of file
+    uvicorn.run("server:app", host="0.0.0.0", port=8001)
